import requests

def downloadFile(url:str, file:str):
    response = requests.get(str(url))

    with open(file, 'wb') as f:
        f.write(response.content)

if __name__ == '__main__':
    downloadFile('https://transfer.sh/2olwuBElm6/hello.txt', 'hello.txt')


from setuptools import setup

readme = open("./README.md", "r")

setup(
    name='transfershpy',
    packages=['transfershpy'],
    version='1.1',
    description='Use transfer.sh in python',
    long_description=readme.read(),
    long_description_content_type='text/markdown',
    author='RinkaDev',
    author_email='rinkadevoficial@gmail.com',
    url='https://github.com/RinkaGI/transfer.py',
    download_url='https://github.com/RinkaGI/transfer.py/tarball/1.1',
    keywords=['transfer', 'upload', 'cloud'],
    classifiers=[ ],
    license='MIT',
    include_package_data=True
)


def getDownloadPage(link:str):
    if link.startswith("https://transfer.sh/"):
        parts = link.split("/")
        if len(parts) == 5 and parts[3] != "get":
            parts.insert(3, "get")
            return "/".join(parts)
    return None


import requests

def uploadFile(file:str, url:str, maxDays=14, maxDownloads = None):
    headers = {
        'Max-Days': str(maxDays)
    }

    if maxDownloads is not None:
        headers['Max-Downloads'] = str(maxDownloads)

    with open(file, 'rb') as f:
        data = f.read()

    response = requests.put(url, headers = headers, data=data)

    return response.text

if __name__ == '__main__':
    uploadFile('hello.txt', 'https://transfer.sh/hello.txt')

    ## you can choose max days or max downloads

    uploadFile('hello.txt', 'https://transfer.sh/hello.xt', maxDays=30, maxDownloads=5)